@@ -1,7 +1,7 @@
 """
 Type annotations for chime-sdk-messaging service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/literals/)
 
 Usage::
 
@@ -32,7 +32,10 @@ __all__ = (
     "InvocationTypeType",
     "PushNotificationTypeType",
     "SortOrderType",
+    "ChimeSDKMessagingServiceName",
     "ServiceName",
+    "ResourceServiceName",
+    "RegionName",
 )
 
 
@@ -64,6 +67,7 @@ FallbackActionType = Literal["ABORT", "CONTINUE"]
 InvocationTypeType = Literal["ASYNC"]
 PushNotificationTypeType = Literal["DEFAULT", "VOIP"]
 SortOrderType = Literal["ASCENDING", "DESCENDING"]
+ChimeSDKMessagingServiceName = Literal["chime-sdk-messaging"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -97,6 +101,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -351,3 +356,16 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
+RegionName = Literal["us-east-1"]
